summaryrefslogtreecommitdiff
path: root/vendor/thecodingmachine/safe/generated/apache.php
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/thecodingmachine/safe/generated/apache.php')
-rw-r--r--vendor/thecodingmachine/safe/generated/apache.php68
1 files changed, 45 insertions, 23 deletions
diff --git a/vendor/thecodingmachine/safe/generated/apache.php b/vendor/thecodingmachine/safe/generated/apache.php
index e71c32d7b..2bb3632a9 100644
--- a/vendor/thecodingmachine/safe/generated/apache.php
+++ b/vendor/thecodingmachine/safe/generated/apache.php
@@ -26,8 +26,6 @@ function apache_get_version(): string
* Retrieve an Apache environment variable specified by
* variable.
*
- * This function requires Apache 2 otherwise it's undefined.
- *
* @param string $variable The Apache environment variable
* @param bool $walk_to_top Whether to get the top-level variable available to all Apache layers.
* @return string The value of the Apache environment variable on success
@@ -46,18 +44,46 @@ function apache_getenv(string $variable, bool $walk_to_top = false): string
/**
- * Fetches all HTTP request headers from the current request. Works in the
- * Apache, FastCGI, CLI, FPM and NSAPI server module
- * in Netscape/iPlanet/SunONE webservers.
- *
- * @return array An associative array of all the HTTP headers in the current request.
+ * This performs a partial request for a URI. It goes just far
+ * enough to obtain all the important information about the given
+ * resource.
+ *
+ * @param string $filename The filename (URI) that's being requested.
+ * @return object An object of related URI information. The properties of
+ * this object are:
+ *
+ *
+ * status
+ * the_request
+ * status_line
+ * method
+ * content_type
+ * handler
+ * uri
+ * filename
+ * path_info
+ * args
+ * boundary
+ * no_cache
+ * no_local_copy
+ * allowed
+ * send_bodyct
+ * bytes_sent
+ * byterange
+ * clength
+ * unparsed_uri
+ * mtime
+ * request_time
+ *
+ *
+ * Returns FALSE on failure.
* @throws ApacheException
*
*/
-function apache_request_headers(): array
+function apache_lookup_uri(string $filename): object
{
error_clear_last();
- $result = \apache_request_headers();
+ $result = \apache_lookup_uri($filename);
if ($result === false) {
throw ApacheException::createFromPhpError();
}
@@ -66,31 +92,27 @@ function apache_request_headers(): array
/**
- * apache_reset_timeout resets the Apache write timer,
- * which defaults to 300 seconds. With set_time_limit(0);
- * ignore_user_abort(true) and periodic
- * apache_reset_timeout calls, Apache can theoretically
- * run forever.
- *
- * This function requires Apache 1.
+ * Fetches all HTTP request headers from the current request. Works in the
+ * Apache, FastCGI, CLI, and FPM webservers.
*
+ * @return array An associative array of all the HTTP headers in the current request.
* @throws ApacheException
*
*/
-function apache_reset_timeout(): void
+function apache_request_headers(): array
{
error_clear_last();
- $result = \apache_reset_timeout();
+ $result = \apache_request_headers();
if ($result === false) {
throw ApacheException::createFromPhpError();
}
+ return $result;
}
/**
* Fetch all HTTP response headers. Works in the
- * Apache, FastCGI, CLI, FPM and NSAPI server module
- * in Netscape/iPlanet/SunONE webservers.
+ * Apache, FastCGI, CLI, and FPM webservers.
*
* @return array An array of all Apache response headers on success.
* @throws ApacheException
@@ -163,14 +185,14 @@ function getallheaders(): array
* To run the sub-request, all buffers are terminated and flushed to the
* browser, pending headers are sent too.
*
* @param string $filename The file that the virtual command will be performed on.
* @throws ApacheException
*
*/
-function virtual(string $filename): void
+function virtual(string $uri): void
{
error_clear_last();
- $result = \virtual($filename);
+ $result = \virtual($uri);
if ($result === false) {
throw ApacheException::createFromPhpError();
}
@@ -163,14 +185,14 @@ function getallheaders(): array
* browser, pending headers are sent too.
*
- * @param string $filename The file that the virtual command will be performed on.
+ * @param string $uri The file that the virtual command will be performed on.
* @throws ApacheException
*